Welcome to pyMSO4's documentation!
==================================

A python library for interfacing with the Tektronix MSO4 oscilloscopes (tested
with MSO44 firmware version "non-windows V2.0.3.950").

See :doc:`usage` for a quick start guide and examples. It is advisable to read
the `report <https://github.com/ceres-c/pyMSO4/blob/master/report/report.pdf>`_
for an overview of the rationale behind the library and additional information
on some issues that were encountered during development, and how to solve them.

If you're here because you think it's fun to get root on an oscilloscope, see
Appendix C of the `report
<https://github.com/ceres-c/pyMSO4/blob/master/report/report.pdf>`_ for the
details.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   building
   usage
   api

Dependencies
------------
- pyvisa
- pyvisa-py
- pyusb

Build dependencies
------------------
See :doc:`building`

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`